summaryrefslogtreecommitdiffstats
path: root/ksirc/KSPrefs
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/KSPrefs')
-rw-r--r--ksirc/KSPrefs/ksprefs.cpp4
-rw-r--r--ksirc/KSPrefs/ksprefs.h3
-rw-r--r--ksirc/KSPrefs/page_autoconnect.cpp44
-rw-r--r--ksirc/KSPrefs/page_autoconnect.h3
-rw-r--r--ksirc/KSPrefs/page_autoconnectbase.ui84
-rw-r--r--ksirc/KSPrefs/page_colors.cpp16
-rw-r--r--ksirc/KSPrefs/page_colors.h3
-rw-r--r--ksirc/KSPrefs/page_colorsbase.ui156
-rw-r--r--ksirc/KSPrefs/page_font.cpp10
-rw-r--r--ksirc/KSPrefs/page_font.h9
-rw-r--r--ksirc/KSPrefs/page_general.cpp8
-rw-r--r--ksirc/KSPrefs/page_general.h3
-rw-r--r--ksirc/KSPrefs/page_generalbase.ui70
-rw-r--r--ksirc/KSPrefs/page_irccolors.cpp2
-rw-r--r--ksirc/KSPrefs/page_irccolors.h3
-rw-r--r--ksirc/KSPrefs/page_irccolorsbase.ui152
-rw-r--r--ksirc/KSPrefs/page_looknfeel.cpp2
-rw-r--r--ksirc/KSPrefs/page_looknfeel.h3
-rw-r--r--ksirc/KSPrefs/page_looknfeelbase.ui50
-rw-r--r--ksirc/KSPrefs/page_rmbmenu.cpp2
-rw-r--r--ksirc/KSPrefs/page_rmbmenu.h3
-rw-r--r--ksirc/KSPrefs/page_rmbmenubase.ui48
-rw-r--r--ksirc/KSPrefs/page_servchan.cpp2
-rw-r--r--ksirc/KSPrefs/page_servchan.h3
-rw-r--r--ksirc/KSPrefs/page_servchanbase.ui28
-rw-r--r--ksirc/KSPrefs/page_shortcuts.cpp4
-rw-r--r--ksirc/KSPrefs/page_shortcuts.h3
-rw-r--r--ksirc/KSPrefs/page_shortcutsbase.ui12
-rw-r--r--ksirc/KSPrefs/page_startup.cpp8
-rw-r--r--ksirc/KSPrefs/page_startup.h3
-rw-r--r--ksirc/KSPrefs/page_startupbase.ui28
31 files changed, 390 insertions, 379 deletions
diff --git a/ksirc/KSPrefs/ksprefs.cpp b/ksirc/KSPrefs/ksprefs.cpp
index 40ccc56f..6deb550c 100644
--- a/ksirc/KSPrefs/ksprefs.cpp
+++ b/ksirc/KSPrefs/ksprefs.cpp
@@ -26,10 +26,10 @@
#include "page_looknfeel.h"
#include "page_shortcuts.h"
-KSPrefs::KSPrefs(TQWidget * parent, const char * name):
+KSPrefs::KSPrefs(TQWidget * tqparent, const char * name):
KDialogBase(KDialogBase::IconList, i18n("Configure KSirc"),
KDialogBase::Help | KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel | KDialogBase::Default,
- KDialogBase::Ok, parent, name)
+ KDialogBase::Ok, tqparent, name)
{
setWFlags( getWFlags() | WDestructiveClose );
TQFrame *itemLooknFeel= addPage( i18n( "Look and Feel" ), i18n( "Controls how kSirc looks" ), BarIcon( "ksirc", KIcon::SizeMedium ) );
diff --git a/ksirc/KSPrefs/ksprefs.h b/ksirc/KSPrefs/ksprefs.h
index 1e5beaf0..51ae6562 100644
--- a/ksirc/KSPrefs/ksprefs.h
+++ b/ksirc/KSPrefs/ksprefs.h
@@ -29,8 +29,9 @@ class KSPrefs : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KSPrefs(TQWidget * parent = 0, const char * name = 0);
+ KSPrefs(TQWidget * tqparent = 0, const char * name = 0);
~KSPrefs();
public slots:
diff --git a/ksirc/KSPrefs/page_autoconnect.h b/ksirc/KSPrefs/page_autoconnect.h
index 04b5b821..cce0f810 100644
--- a/ksirc/KSPrefs/page_autoconnect.h
+++ b/ksirc/KSPrefs/page_autoconnect.h
@@ -7,9 +7,10 @@
class PageAutoConnect : public PageAutoConnectBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageAutoConnect( TQWidget* parent = 0, const char* name = 0);
+ PageAutoConnect( TQWidget* tqparent = 0, const char* name = 0);
~PageAutoConnect();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_autoconnectbase.ui b/ksirc/KSPrefs/page_autoconnectbase.ui
index 71aafb49..815598ba 100644
--- a/ksirc/KSPrefs/page_autoconnectbase.ui
+++ b/ksirc/KSPrefs/page_autoconnectbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>PageAutoConnectBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageAutoConnectBase</cstring>
</property>
@@ -77,7 +77,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox12</cstring>
</property>
@@ -88,23 +88,23 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout13</cstring>
+ <cstring>tqlayout13</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout9</cstring>
+ <cstring>tqlayout9</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelSever</cstring>
</property>
@@ -112,22 +112,22 @@
<string>Server:</string>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>ServerLE</cstring>
</property>
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout12</cstring>
+ <cstring>tqlayout12</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelPort</cstring>
</property>
@@ -145,15 +145,15 @@
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout11</cstring>
+ <cstring>tqlayout11</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelPass</cstring>
</property>
@@ -161,22 +161,22 @@
<string>Server password:</string>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>PassLE</cstring>
</property>
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout15</cstring>
+ <cstring>tqlayout15</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelSSL</cstring>
</property>
@@ -187,7 +187,7 @@
<cstring>PortKI</cstring>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>sslCB</cstring>
</property>
@@ -199,23 +199,23 @@
</widget>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout12</cstring>
+ <cstring>tqlayout12</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout3</cstring>
+ <cstring>tqlayout3</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelChan</cstring>
</property>
@@ -226,22 +226,22 @@
<cstring>ChannelLE</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>ChannelLE</cstring>
</property>
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout9</cstring>
+ <cstring>tqlayout9</cstring>
</property>
<vbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabelKey</cstring>
</property>
@@ -252,7 +252,7 @@
<cstring>KeyLE</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>KeyLE</cstring>
</property>
@@ -261,15 +261,15 @@
</widget>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout17</cstring>
+ <cstring>tqlayout17</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>NewPB</cstring>
</property>
@@ -277,7 +277,7 @@
<string>&amp;New</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>AddPB</cstring>
</property>
@@ -285,7 +285,7 @@
<string>&amp;Add</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>DeletePB</cstring>
</property>
@@ -356,9 +356,9 @@
</connection>
<connection>
<sender>KLVAutoConnect</sender>
- <signal>clicked(QListViewItem*)</signal>
+ <signal>clicked(TQListViewItem*)</signal>
<receiver>PageAutoConnectBase</receiver>
- <slot>kvl_clicked(QListViewItem*)</slot>
+ <slot>kvl_clicked(TQListViewItem*)</slot>
</connection>
</connections>
<tabstops>
@@ -373,16 +373,16 @@
<tabstop>AddPB</tabstop>
<tabstop>DeletePB</tabstop>
</tabstops>
-<slots>
+<Q_SLOTS>
<slot>item_changed()</slot>
<slot>new_pressed()</slot>
<slot>add_pressed()</slot>
<slot>delete_pressed()</slot>
- <slot>KLVAutoConnect_clicked(QListViewItem*)</slot>
- <slot>kcl_clicked(QListViewItem *)</slot>
- <slot>kvl_clicked(QListViewItem*)</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+ <slot>KLVAutoConnect_clicked(TQListViewItem*)</slot>
+ <slot>kcl_clicked(TQListViewItem *)</slot>
+ <slot>kvl_clicked(TQListViewItem*)</slot>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klistview.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/ksirc/KSPrefs/page_colors.cpp b/ksirc/KSPrefs/page_colors.cpp
index e7b36af4..a31acb64 100644
--- a/ksirc/KSPrefs/page_colors.cpp
+++ b/ksirc/KSPrefs/page_colors.cpp
@@ -19,7 +19,7 @@
#include <kcolorbutton.h>
#include <kdebug.h>
-PageColors::PageColors( TQWidget *parent, const char *name ) : PageColorsBase( parent, name)
+PageColors::PageColors( TQWidget *tqparent, const char *name ) : PageColorsBase( tqparent, name)
{
changing = 0;
m_dcol.setAutoDelete(true);
@@ -162,13 +162,13 @@ void PageColors::readConfig( const KSOColors *opts )
conf->setGroup("ColourSchemes");
themeLB->clear();
TQStringList names = conf->readListEntry("Names");
- if(names.contains("Custom")){
- names.remove(names.find("Custom"));
+ if(names.tqcontains("Custom")){
+ names.remove(names.tqfind("Custom"));
}
names.prepend("Custom");
themeLB->insertStringList(names);
- if(themeLB->findItem(ksopts->colourTheme, Qt::ExactMatch))
- themeLB->setCurrentItem(themeLB->findItem(ksopts->colourTheme, Qt::ExactMatch));
+ if(themeLB->tqfindItem(ksopts->colourTheme, TQt::ExactMatch))
+ themeLB->setCurrentItem(themeLB->tqfindItem(ksopts->colourTheme, TQt::ExactMatch));
else
themeLB->setCurrentItem(0);
themeLE->setText(themeLB->currentText());
@@ -243,7 +243,7 @@ void PageColors::themeAddPB_clicked()
kdDebug(5008) << "Got add: " << themeLB->currentText() << endl;
- m_dcol.replace(name, new KSOColors());
+ m_dcol.tqreplace(name, new KSOColors());
m_dcol[name]->backgroundColor = backCBtn->color();
m_dcol[name]->selBackgroundColor = selBackCBtn->color();
@@ -257,11 +257,11 @@ void PageColors::themeAddPB_clicked()
m_dcol[name]->nickForeground = nickFGCBtn->color();
m_dcol[name]->nickBackground = nickBGCBtn->color();
- if(themeLB->findItem(name, Qt::ExactMatch) == 0){
+ if(themeLB->tqfindItem(name, TQt::ExactMatch) == 0){
themeLB->insertItem(name);
}
- themeLB->setCurrentItem(themeLB->findItem(name, Qt::ExactMatch));
+ themeLB->setCurrentItem(themeLB->tqfindItem(name, TQt::ExactMatch));
}
diff --git a/ksirc/KSPrefs/page_colors.h b/ksirc/KSPrefs/page_colors.h
index 5401aecc..4b2313e4 100644
--- a/ksirc/KSPrefs/page_colors.h
+++ b/ksirc/KSPrefs/page_colors.h
@@ -20,9 +20,10 @@
class PageColors : public PageColorsBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageColors( TQWidget *parent = 0, const char *name = 0 );
+ PageColors( TQWidget *tqparent = 0, const char *name = 0 );
~PageColors();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_colorsbase.ui b/ksirc/KSPrefs/page_colorsbase.ui
index 498c9c23..cffcc4cc 100644
--- a/ksirc/KSPrefs/page_colorsbase.ui
+++ b/ksirc/KSPrefs/page_colorsbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>PageColorsBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageColorsBase</cstring>
</property>
@@ -22,11 +22,11 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QTabWidget">
+ <widget class="TQTabWidget">
<property name="name">
<cstring>tabWidget2</cstring>
</property>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -37,7 +37,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>chatColorsGB</cstring>
</property>
@@ -54,7 +54,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>chanMsgLabel</cstring>
</property>
@@ -65,7 +65,7 @@
<cstring>chanMsgCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>genericTextLabel</cstring>
</property>
@@ -76,7 +76,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>errorLabel</cstring>
</property>
@@ -87,7 +87,7 @@
<cstring>errorCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>infoLabel</cstring>
</property>
@@ -98,7 +98,7 @@
<cstring>infoCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="1" column="2">
+ <widget class="TQLabel" row="1" column="2">
<property name="name">
<cstring>backgrndLabel</cstring>
</property>
@@ -113,7 +113,7 @@
<property name="name">
<cstring>genericTextCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -123,7 +123,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="2" column="2">
+ <widget class="TQLabel" row="2" column="2">
<property name="name">
<cstring>backgrndLabel_2</cstring>
</property>
@@ -144,7 +144,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -155,7 +155,7 @@
<property name="name">
<cstring>linkCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -169,7 +169,7 @@
<property name="name">
<cstring>backCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -183,7 +183,7 @@
<property name="name">
<cstring>errorCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -193,7 +193,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>backgrndLabel_2_2</cstring>
</property>
@@ -208,7 +208,7 @@
<property name="name">
<cstring>infoCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -222,7 +222,7 @@
<property name="name">
<cstring>chanMsgCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -236,7 +236,7 @@
<property name="name">
<cstring>selBackCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -250,7 +250,7 @@
<property name="name">
<cstring>selForeCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -260,7 +260,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="3" column="2">
+ <widget class="TQLabel" row="3" column="2">
<property name="name">
<cstring>backgrndLabel_2_2_2</cstring>
</property>
@@ -271,7 +271,7 @@
<cstring>backCBtn</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="0" rowspan="1" colspan="5">
+ <widget class="TQCheckBox" row="4" column="0" rowspan="1" colspan="5">
<property name="name">
<cstring>nickFGColorCB</cstring>
</property>
@@ -281,7 +281,7 @@
</widget>
</grid>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox11</cstring>
</property>
@@ -292,17 +292,17 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLineEdit" row="0" column="0" rowspan="1" colspan="2">
+ <widget class="TQLineEdit" row="0" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>themeLE</cstring>
</property>
</widget>
- <widget class="QListBox" row="1" column="0" rowspan="4" colspan="1">
+ <widget class="TQListBox" row="1" column="0" rowspan="4" colspan="1">
<property name="name">
<cstring>themeLB</cstring>
</property>
</widget>
- <widget class="QPushButton" row="1" column="1">
+ <widget class="TQPushButton" row="1" column="1">
<property name="name">
<cstring>themeNewPB</cstring>
</property>
@@ -310,7 +310,7 @@
<string>&amp;New</string>
</property>
</widget>
- <widget class="QPushButton" row="2" column="1">
+ <widget class="TQPushButton" row="2" column="1">
<property name="name">
<cstring>themeAddPB</cstring>
</property>
@@ -318,7 +318,7 @@
<string>&amp;Add</string>
</property>
</widget>
- <widget class="QPushButton" row="3" column="1">
+ <widget class="TQPushButton" row="3" column="1">
<property name="name">
<cstring>themeDelPB</cstring>
</property>
@@ -336,7 +336,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>40</height>
@@ -347,7 +347,7 @@
</widget>
</vbox>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>tab</cstring>
</property>
@@ -358,7 +358,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox5</cstring>
</property>
@@ -369,7 +369,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>nickMatchLabel_2_2</cstring>
</property>
@@ -384,7 +384,7 @@
<property name="name">
<cstring>ownNickCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -394,7 +394,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>ownNickBoldCB</cstring>
</property>
@@ -402,7 +402,7 @@
<string>Bold</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>ownNickRevCB</cstring>
</property>
@@ -410,7 +410,7 @@
<string>Reverse</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>ownNickUlCB</cstring>
</property>
@@ -428,7 +428,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>202</width>
<height>20</height>
@@ -437,7 +437,7 @@
</spacer>
</hbox>
</widget>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>buttonGroup1</cstring>
</property>
@@ -451,7 +451,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton" row="0" column="0" rowspan="1" colspan="6">
+ <widget class="TQRadioButton" row="0" column="0" rowspan="1" colspan="6">
<property name="name">
<cstring>noOtherColRB</cstring>
</property>
@@ -459,7 +459,7 @@
<string>N&amp;o nick colors</string>
</property>
</widget>
- <widget class="QRadioButton" row="1" column="0" rowspan="1" colspan="6">
+ <widget class="TQRadioButton" row="1" column="0" rowspan="1" colspan="6">
<property name="name">
<cstring>autoOtherColRB</cstring>
</property>
@@ -467,7 +467,7 @@
<string>Au&amp;to nick colorization</string>
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>fixedOtherColRB</cstring>
</property>
@@ -475,7 +475,7 @@
<string>Fi&amp;xed</string>
</property>
</widget>
- <widget class="QLabel" row="2" column="1">
+ <widget class="TQLabel" row="2" column="1">
<property name="name">
<cstring>nickFGColorLabel</cstring>
</property>
@@ -490,13 +490,13 @@
<property name="name">
<cstring>nickFGCBtn</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -506,7 +506,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="2" column="3">
+ <widget class="TQLabel" row="2" column="3">
<property name="name">
<cstring>nickBGColorLabel</cstring>
</property>
@@ -524,7 +524,7 @@
<property name="enabled">
<bool>false</bool>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -544,7 +544,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>83</width>
<height>21</height>
@@ -553,7 +553,7 @@
</spacer>
</grid>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>nickGB</cstring>
</property>
@@ -564,15 +564,15 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout12</cstring>
+ <cstring>tqlayout12</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>nickMatchLabel_2</cstring>
</property>
@@ -587,7 +587,7 @@
<property name="name">
<cstring>ownContainNickCBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -607,7 +607,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>169</width>
<height>21</height>
@@ -616,15 +616,15 @@
</spacer>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout11</cstring>
+ <cstring>tqlayout11</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>nickMatchLabel_2_3</cstring>
</property>
@@ -635,7 +635,7 @@
<cstring>ownNickCBtn</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>msg1LE</cstring>
</property>
@@ -644,7 +644,7 @@
<property name="name">
<cstring>msg1CBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -654,7 +654,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>msg1Regex</cstring>
</property>
@@ -672,7 +672,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>104</width>
<height>21</height>
@@ -681,15 +681,15 @@
</spacer>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
- <cstring>layout10</cstring>
+ <cstring>tqlayout10</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>nickMatchLabel_2_3_2</cstring>
</property>
@@ -700,7 +700,7 @@
<cstring>ownNickCBtn</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>msg2LE</cstring>
</property>
@@ -709,7 +709,7 @@
<property name="name">
<cstring>msg2CBtn</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -719,7 +719,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>msg2Regex</cstring>
</property>
@@ -737,7 +737,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>104</width>
<height>21</height>
@@ -748,7 +748,7 @@
</widget>
</vbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>colorCodesGB</cstring>
</property>
@@ -765,7 +765,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>allowKSircColorsCB</cstring>
</property>
@@ -776,7 +776,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>allowMIRCColorsCB</cstring>
</property>
@@ -797,7 +797,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>20</height>
@@ -816,7 +816,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>31</width>
<height>16</height>
@@ -915,9 +915,9 @@
</connection>
<connection>
<sender>themeLB</sender>
- <signal>clicked(QListBoxItem*)</signal>
+ <signal>clicked(TQListBoxItem*)</signal>
<receiver>PageColorsBase</receiver>
- <slot>theme_clicked(QListBoxItem*)</slot>
+ <slot>theme_clicked(TQListBoxItem*)</slot>
</connection>
<connection>
<sender>themeLB</sender>
@@ -1049,8 +1049,8 @@
<tabstop>themeAddPB</tabstop>
<tabstop>themeDelPB</tabstop>
</tabstops>
-<slots>
- <slot>theme_clicked(QListBoxItem*)</slot>
+<Q_SLOTS>
+ <slot>theme_clicked(TQListBoxItem*)</slot>
<slot>themeNewPB_clicked()</slot>
<slot>themeDelPB_clicked()</slot>
<slot>themeAddPB_clicked()</slot>
@@ -1058,6 +1058,6 @@
<slot>setColourEnabled()</slot>
<slot>coloursSetEnable()</slot>
<slot>changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksirc/KSPrefs/page_font.cpp b/ksirc/KSPrefs/page_font.cpp
index 5ea0dd9b..d10f8925 100644
--- a/ksirc/KSPrefs/page_font.cpp
+++ b/ksirc/KSPrefs/page_font.cpp
@@ -1,11 +1,11 @@
#include "page_font.h"
#include "tqapplication.h"
-PageFont::PageFont( TQWidget *parent, const char *name ) :
- TQWidget( parent, name)
+PageFont::PageFont( TQWidget *tqparent, const char *name ) :
+ TQWidget( tqparent, name)
{
- layout = new TQHBoxLayout(this);
+ tqlayout = new TQHBoxLayout(this);
fontchooser = new KFontChooser(this);
- layout->addWidget(fontchooser);
+ tqlayout->addWidget(fontchooser);
connect(fontchooser,TQT_SIGNAL(fontSelected ( const TQFont&)), this, TQT_SLOT(update()));
}
@@ -21,7 +21,7 @@ void PageFont::update( void ){
void PageFont::saveConfig( void )
{
ksopts->defaultFont = fontchooser->font();
- TQApplication::setFont(fontchooser->font(), true, "KSirc::TextView" );
+ TQApplication::tqsetFont(fontchooser->font(), true, "KSirc::TextView" );
}
void PageFont::readConfig( const KSOColors * opts )
diff --git a/ksirc/KSPrefs/page_font.h b/ksirc/KSPrefs/page_font.h
index 44940170..d07babad 100644
--- a/ksirc/KSPrefs/page_font.h
+++ b/ksirc/KSPrefs/page_font.h
@@ -1,7 +1,7 @@
#ifndef _PAGE_FONT
#define _PAGE_FONT
#include <kfontdialog.h> // For the font selection widget
-#include <tqlayout.h> // For the layout
+#include <tqlayout.h> // For the tqlayout
#include "ksopts.h" // For storing the info.
/**
@@ -9,15 +9,16 @@
*
* @author Markus Weimer <markus.weimer@web.de>
*/
-class PageFont : public QWidget
+class PageFont : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create the Widget
*/
- PageFont( TQWidget *parent = 0, const char *name = 0 );
+ PageFont( TQWidget *tqparent = 0, const char *name = 0 );
/*
@@ -56,7 +57,7 @@ class PageFont : public QWidget
private:
KFontChooser* fontchooser; /** The font choosing widget from kdelib */
- TQHBoxLayout* layout;
+ TQHBoxLayout* tqlayout;
};
#endif
diff --git a/ksirc/KSPrefs/page_general.cpp b/ksirc/KSPrefs/page_general.cpp
index 51a78ec3..119201e1 100644
--- a/ksirc/KSPrefs/page_general.cpp
+++ b/ksirc/KSPrefs/page_general.cpp
@@ -15,7 +15,7 @@
#include "page_general.h"
#include "../servercontroller.h"
-PageGeneral::PageGeneral( TQWidget *parent, const char *name ) : PageGeneralBase( parent, name)
+PageGeneral::PageGeneral( TQWidget *tqparent, const char *name ) : PageGeneralBase( tqparent, name)
{
}
@@ -87,15 +87,15 @@ void PageGeneral::readConfig( const KSOGeneral *opts )
// remove utf16/ucs2 as it just doesn't work for IRC
TQStringList::Iterator encodingIt = encodings.begin();
while ( encodingIt != encodings.end() ) {
- if ( ( *encodingIt ).find( "utf16" ) != -1 ||
- ( *encodingIt ).find( "iso-10646" ) != -1 )
+ if ( ( *encodingIt ).tqfind( "utf16" ) != -1 ||
+ ( *encodingIt ).tqfind( "iso-10646" ) != -1 )
encodingIt = encodings.remove( encodingIt );
else
++encodingIt;
}
encodings.prepend( i18n( "Default" ) );
encodingsCB->insertStringList(encodings);
- int eindex = encodings.findIndex(ksopts->channel["global"]["global"].encoding);
+ int eindex = encodings.tqfindIndex(ksopts->channel["global"]["global"].encoding);
if(eindex == -1)
encodingsCB->setCurrentItem(0);
else
diff --git a/ksirc/KSPrefs/page_general.h b/ksirc/KSPrefs/page_general.h
index 253d6623..e7e3227c 100644
--- a/ksirc/KSPrefs/page_general.h
+++ b/ksirc/KSPrefs/page_general.h
@@ -16,9 +16,10 @@
class PageGeneral : public PageGeneralBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageGeneral( TQWidget *parent = 0, const char *name = 0 );
+ PageGeneral( TQWidget *tqparent = 0, const char *name = 0 );
~PageGeneral();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_generalbase.ui b/ksirc/KSPrefs/page_generalbase.ui
index e8ae7e8f..d4dec93b 100644
--- a/ksirc/KSPrefs/page_generalbase.ui
+++ b/ksirc/KSPrefs/page_generalbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>PageGeneralBase</class>
-<widget class="QFrame">
+<widget class="TQFrame">
<property name="name">
<cstring>PageGeneralBase</cstring>
</property>
@@ -12,7 +12,7 @@
<height>489</height>
</rect>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>425</width>
<height>0</height>
@@ -34,7 +34,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>miscGB</cstring>
</property>
@@ -51,7 +51,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget" row="5" column="1">
+ <widget class="TQLayoutWidget" row="5" column="1">
<property name="name">
<cstring>Layout11</cstring>
</property>
@@ -65,11 +65,11 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>historyItemsLabel</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>120</width>
<height>32767</height>
@@ -82,7 +82,7 @@
<cstring>historySB</cstring>
</property>
</widget>
- <widget class="QSpinBox">
+ <widget class="TQSpinBox">
<property name="name">
<cstring>historySB</cstring>
</property>
@@ -112,7 +112,7 @@
</widget>
</hbox>
</widget>
- <widget class="QCheckBox" row="2" column="1">
+ <widget class="TQCheckBox" row="2" column="1">
<property name="name">
<cstring>publicAway</cstring>
</property>
@@ -126,7 +126,7 @@
<string>If this is checked, you will see the messages when a user selects the away option. By default this option is not checked.</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>autoCreateWindowCB</cstring>
</property>
@@ -140,7 +140,7 @@
<string>If selected, KSirc will automatically create a new window for each user who sends a /msg command to you. If not selected, any text sent to you with /msg is displayed in the current window and you can use /query username to create a window to chat to that user.</string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="0">
+ <widget class="TQCheckBox" row="2" column="0">
<property name="name">
<cstring>autoCreateWindowForNoticeCB</cstring>
</property>
@@ -148,7 +148,7 @@
<string>Auto create &amp;on notice</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="1">
+ <widget class="TQCheckBox" row="1" column="1">
<property name="name">
<cstring>autoRejoinCB</cstring>
</property>
@@ -162,7 +162,7 @@
<string>If selected, it allows you to rejoin channels automatically if you are disconnected.</string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="1">
+ <widget class="TQCheckBox" row="4" column="1">
<property name="name">
<cstring>dockPopupsCB</cstring>
</property>
@@ -170,7 +170,7 @@
<string>Dock &amp;passive popups</string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="0">
+ <widget class="TQCheckBox" row="4" column="0">
<property name="name">
<cstring>displayTopicCB</cstring>
</property>
@@ -184,7 +184,7 @@
<string>Displays the topic of the current channel in the window caption. If not selected, the topic is only displayed inside the window.</string>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="1">
+ <widget class="TQCheckBox" row="0" column="1">
<property name="name">
<cstring>colorPickerPopupCB</cstring>
</property>
@@ -198,7 +198,7 @@
<string>If selected, a popup window from which to select the color of your text is presented when you press Ctrl K. If not, you have to type the color codes manually.</string>
</property>
</widget>
- <widget class="QCheckBox" row="5" column="0">
+ <widget class="TQCheckBox" row="5" column="0">
<property name="name">
<cstring>oneLineEditCB</cstring>
</property>
@@ -206,7 +206,7 @@
<string>One line te&amp;xt entry box</string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="1">
+ <widget class="TQCheckBox" row="3" column="1">
<property name="name">
<cstring>useColourNickListCB</cstring>
</property>
@@ -230,14 +230,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>16</width>
<height>21</height>
</size>
</property>
</spacer>
- <widget class="QCheckBox" row="3" column="0">
+ <widget class="TQCheckBox" row="3" column="0">
<property name="name">
<cstring>nickCompletionCB</cstring>
</property>
@@ -251,7 +251,7 @@
<string>If selected, switches nickname completion on. Nickname completion works as follows: Type the first letters of a user's nickname, press the Tab key, the text you typed will be completed to match the username, including changes in capitalization if necessary.</string>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="0">
+ <widget class="TQCheckBox" row="0" column="0">
<property name="name">
<cstring>dockedOnlyCB</cstring>
</property>
@@ -265,7 +265,7 @@
<string>This allows KSirc to be docked in the system tray. By default this is not enabled. When KSirc is docked in the system tray, you are able to access several options by clicking on the KSirc icon. When you close KSirc window, the icon stays in the systray until you quit KSirc.</string>
</property>
</widget>
- <widget class="QCheckBox" row="6" column="0">
+ <widget class="TQCheckBox" row="6" column="0">
<property name="name">
<cstring>autoSaveHistoryCB</cstring>
</property>
@@ -275,7 +275,7 @@
</widget>
</grid>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox4</cstring>
</property>
@@ -286,7 +286,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>timeStampCB</cstring>
</property>
@@ -300,7 +300,7 @@
<string>Prepends each thing said in the channel with the time it was said, in the form [HH:MM:SS].</string>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="0" rowspan="1" colspan="2">
+ <widget class="TQCheckBox" row="0" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>applyGloballyCB</cstring>
</property>
@@ -314,7 +314,7 @@
<string>If this is selected, the settings in this tab will override each channel's options so these settings will be applied in each channel, independently of your channel settings in the Channel menu. This setting will only work until next time you open the configuration dialog and it will be reset unchecked then; this is because you probably do not want to override the existing channels options all the time.</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="1">
+ <widget class="TQCheckBox" row="1" column="1">
<property name="name">
<cstring>showTopicCB</cstring>
</property>
@@ -328,7 +328,7 @@
<string>Displays the channel topic on top of each channel window.</string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="0">
+ <widget class="TQCheckBox" row="2" column="0">
<property name="name">
<cstring>beepCB</cstring>
</property>
@@ -336,7 +336,7 @@
<string>&amp;Beep on change</string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="0">
+ <widget class="TQCheckBox" row="3" column="0">
<property name="name">
<cstring>joinPartCB</cstring>
</property>
@@ -344,7 +344,7 @@
<string>Hide part/join messages</string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="1">
+ <widget class="TQCheckBox" row="2" column="1">
<property name="name">
<cstring>enLoggingCB</cstring>
</property>
@@ -355,15 +355,15 @@
<string></string>
</property>
</widget>
- <widget class="QLayoutWidget" row="4" column="0" rowspan="1" colspan="2">
+ <widget class="TQLayoutWidget" row="4" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>layout2</cstring>
+ <cstring>tqlayout2</cstring>
</property>
<hbox>
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>encodingsL</cstring>
</property>
@@ -374,7 +374,7 @@
<cstring>encodingsCB</cstring>
</property>
</widget>
- <widget class="QComboBox">
+ <widget class="TQComboBox">
<property name="name">
<cstring>encodingsCB</cstring>
</property>
@@ -393,7 +393,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>31</width>
<height>71</height>
@@ -531,10 +531,10 @@
<tabstop>showTopicCB</tabstop>
<tabstop>enLoggingCB</tabstop>
</tabstops>
-<slots>
+<Q_SLOTS>
<slot access="protected">setPreviewPixmap(bool)</slot>
<slot access="protected">showWallpaperPixmap(const QString &amp;)</slot>
<slot>changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksirc/KSPrefs/page_irccolors.cpp b/ksirc/KSPrefs/page_irccolors.cpp
index 5ed96054..5177dc49 100644
--- a/ksirc/KSPrefs/page_irccolors.cpp
+++ b/ksirc/KSPrefs/page_irccolors.cpp
@@ -14,7 +14,7 @@
#include <kconfig.h>
#include <kcolorbutton.h>
-PageIRCColors::PageIRCColors( TQWidget *parent, const char *name ) : PageIRCColorsBase( parent, name)
+PageIRCColors::PageIRCColors( TQWidget *tqparent, const char *name ) : PageIRCColorsBase( tqparent, name)
{
}
diff --git a/ksirc/KSPrefs/page_irccolors.h b/ksirc/KSPrefs/page_irccolors.h
index 34565b42..843a8391 100644
--- a/ksirc/KSPrefs/page_irccolors.h
+++ b/ksirc/KSPrefs/page_irccolors.h
@@ -16,9 +16,10 @@
class PageIRCColors : public PageIRCColorsBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageIRCColors( TQWidget *parent = 0, const char *name = 0 );
+ PageIRCColors( TQWidget *tqparent = 0, const char *name = 0 );
~PageIRCColors();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_irccolorsbase.ui b/ksirc/KSPrefs/page_irccolorsbase.ui
index 96fc18cc..7b7e31b9 100644
--- a/ksirc/KSPrefs/page_irccolorsbase.ui
+++ b/ksirc/KSPrefs/page_irccolorsbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>PageIRCColorsBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageIRCColorsBase</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>textLabel5</cstring>
</property>
@@ -30,11 +30,11 @@
<string>&lt;p&gt;This selection allows you to control what the colors displayed inline in the channel look like. These colors are used for both mIRC style colors in channels and colorful nicks. The sample box beside the button gives you an example of what it will look like in the channel. The checkbox controls if the color is used for the colorful nick features. Checked means use it.&lt;/p&gt;</string>
</property>
</widget>
- <widget class="QTabWidget">
+ <widget class="TQTabWidget">
<property name="name">
<cstring>tabWidget</cstring>
</property>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>dark</cstring>
</property>
@@ -45,7 +45,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>groupBox16</cstring>
</property>
@@ -56,7 +56,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>genericTextLabel_2</cstring>
</property>
@@ -71,7 +71,7 @@
<property name="name">
<cstring>CBtn_1</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -81,7 +81,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="1" column="2">
+ <widget class="TQLabel" row="1" column="2">
<property name="name">
<cstring>TL_1</cstring>
</property>
@@ -106,7 +106,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>genericTextLabel</cstring>
</property>
@@ -137,7 +137,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -147,7 +147,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>TL_0</cstring>
</property>
@@ -172,7 +172,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>genericTextLabel_3</cstring>
</property>
@@ -187,7 +187,7 @@
<property name="name">
<cstring>CBtn_2</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -197,7 +197,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="2" column="2">
+ <widget class="TQLabel" row="2" column="2">
<property name="name">
<cstring>TL_2</cstring>
</property>
@@ -222,7 +222,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="4" column="0">
+ <widget class="TQLabel" row="4" column="0">
<property name="name">
<cstring>genericTextLabel_5</cstring>
</property>
@@ -237,7 +237,7 @@
<property name="name">
<cstring>CBtn_4</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -247,7 +247,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="4" column="2">
+ <widget class="TQLabel" row="4" column="2">
<property name="name">
<cstring>TL_4</cstring>
</property>
@@ -264,7 +264,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>genericTextLabel_4</cstring>
</property>
@@ -279,7 +279,7 @@
<property name="name">
<cstring>CBtn_3</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -289,7 +289,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="3" column="2">
+ <widget class="TQLabel" row="3" column="2">
<property name="name">
<cstring>TL_3</cstring>
</property>
@@ -306,7 +306,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>genericTextLabel_6</cstring>
</property>
@@ -321,7 +321,7 @@
<property name="name">
<cstring>CBtn_5</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -331,7 +331,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="5" column="2">
+ <widget class="TQLabel" row="5" column="2">
<property name="name">
<cstring>TL_5</cstring>
</property>
@@ -348,7 +348,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="6" column="0">
+ <widget class="TQLabel" row="6" column="0">
<property name="name">
<cstring>genericTextLabel_7</cstring>
</property>
@@ -363,7 +363,7 @@
<property name="name">
<cstring>CBtn_6</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -373,7 +373,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="6" column="2">
+ <widget class="TQLabel" row="6" column="2">
<property name="name">
<cstring>TL_6</cstring>
</property>
@@ -390,7 +390,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="7" column="0">
+ <widget class="TQLabel" row="7" column="0">
<property name="name">
<cstring>genericTextLabel_8</cstring>
</property>
@@ -405,7 +405,7 @@
<property name="name">
<cstring>CBtn_7</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -415,7 +415,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="7" column="2">
+ <widget class="TQLabel" row="7" column="2">
<property name="name">
<cstring>TL_7</cstring>
</property>
@@ -432,7 +432,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="3">
+ <widget class="TQCheckBox" row="0" column="3">
<property name="name">
<cstring>CBox_0</cstring>
</property>
@@ -448,7 +448,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="3">
+ <widget class="TQCheckBox" row="1" column="3">
<property name="name">
<cstring>CBox_1</cstring>
</property>
@@ -456,7 +456,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="3">
+ <widget class="TQCheckBox" row="2" column="3">
<property name="name">
<cstring>CBox_2</cstring>
</property>
@@ -464,7 +464,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="3">
+ <widget class="TQCheckBox" row="3" column="3">
<property name="name">
<cstring>CBox_3</cstring>
</property>
@@ -472,7 +472,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="3">
+ <widget class="TQCheckBox" row="4" column="3">
<property name="name">
<cstring>CBox_4</cstring>
</property>
@@ -480,7 +480,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="5" column="3">
+ <widget class="TQCheckBox" row="5" column="3">
<property name="name">
<cstring>CBox_5</cstring>
</property>
@@ -488,7 +488,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="6" column="3">
+ <widget class="TQCheckBox" row="6" column="3">
<property name="name">
<cstring>CBox_6</cstring>
</property>
@@ -496,7 +496,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="7" column="3">
+ <widget class="TQCheckBox" row="7" column="3">
<property name="name">
<cstring>CBox_7</cstring>
</property>
@@ -516,7 +516,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>31</width>
<height>41</height>
@@ -525,7 +525,7 @@
</spacer>
</vbox>
</widget>
- <widget class="QWidget">
+ <widget class="TQWidget">
<property name="name">
<cstring>light</cstring>
</property>
@@ -536,7 +536,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>ircColorsGB</cstring>
</property>
@@ -559,7 +559,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>genericTextLabel_11</cstring>
</property>
@@ -570,7 +570,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>genericTextLabel_12</cstring>
</property>
@@ -581,7 +581,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="4" column="0">
+ <widget class="TQLabel" row="4" column="0">
<property name="name">
<cstring>genericTextLabel_13</cstring>
</property>
@@ -592,7 +592,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="5" column="0">
+ <widget class="TQLabel" row="5" column="0">
<property name="name">
<cstring>genericTextLabel_14</cstring>
</property>
@@ -603,7 +603,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="6" column="0">
+ <widget class="TQLabel" row="6" column="0">
<property name="name">
<cstring>genericTextLabel_15</cstring>
</property>
@@ -614,7 +614,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="7" column="0">
+ <widget class="TQLabel" row="7" column="0">
<property name="name">
<cstring>genericTextLabel_16</cstring>
</property>
@@ -629,7 +629,7 @@
<property name="name">
<cstring>CBtn_8</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -643,7 +643,7 @@
<property name="name">
<cstring>CBtn_9</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -657,7 +657,7 @@
<property name="name">
<cstring>CBtn_10</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -671,7 +671,7 @@
<property name="name">
<cstring>CBtn_11</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -685,7 +685,7 @@
<property name="name">
<cstring>CBtn_12</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -699,7 +699,7 @@
<property name="name">
<cstring>CBtn_13</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -713,7 +713,7 @@
<property name="name">
<cstring>CBtn_14</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -727,7 +727,7 @@
<property name="name">
<cstring>CBtn_15</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>60</width>
<height>32767</height>
@@ -737,7 +737,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>genericTextLabel_10</cstring>
</property>
@@ -748,7 +748,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>TL_8</cstring>
</property>
@@ -773,7 +773,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="1" column="2">
+ <widget class="TQLabel" row="1" column="2">
<property name="name">
<cstring>TL_9</cstring>
</property>
@@ -790,7 +790,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="2">
+ <widget class="TQLabel" row="3" column="2">
<property name="name">
<cstring>TL_11</cstring>
</property>
@@ -807,7 +807,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="2" column="2">
+ <widget class="TQLabel" row="2" column="2">
<property name="name">
<cstring>TL_10</cstring>
</property>
@@ -824,7 +824,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="4" column="2">
+ <widget class="TQLabel" row="4" column="2">
<property name="name">
<cstring>TL_12</cstring>
</property>
@@ -841,7 +841,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="5" column="2">
+ <widget class="TQLabel" row="5" column="2">
<property name="name">
<cstring>TL_13</cstring>
</property>
@@ -858,7 +858,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="6" column="2">
+ <widget class="TQLabel" row="6" column="2">
<property name="name">
<cstring>TL_14</cstring>
</property>
@@ -875,7 +875,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QLabel" row="7" column="2">
+ <widget class="TQLabel" row="7" column="2">
<property name="name">
<cstring>TL_15</cstring>
</property>
@@ -892,7 +892,7 @@
<cstring>genericTextCBtn</cstring>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="3">
+ <widget class="TQCheckBox" row="0" column="3">
<property name="name">
<cstring>CBox_8</cstring>
</property>
@@ -908,7 +908,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="3">
+ <widget class="TQCheckBox" row="1" column="3">
<property name="name">
<cstring>CBox_9</cstring>
</property>
@@ -924,7 +924,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="3">
+ <widget class="TQCheckBox" row="2" column="3">
<property name="name">
<cstring>CBox_10</cstring>
</property>
@@ -940,7 +940,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="3">
+ <widget class="TQCheckBox" row="3" column="3">
<property name="name">
<cstring>CBox_11</cstring>
</property>
@@ -956,7 +956,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="4" column="3">
+ <widget class="TQCheckBox" row="4" column="3">
<property name="name">
<cstring>CBox_12</cstring>
</property>
@@ -972,7 +972,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="5" column="3">
+ <widget class="TQCheckBox" row="5" column="3">
<property name="name">
<cstring>CBox_13</cstring>
</property>
@@ -988,7 +988,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="6" column="3">
+ <widget class="TQCheckBox" row="6" column="3">
<property name="name">
<cstring>CBox_14</cstring>
</property>
@@ -1004,7 +1004,7 @@
<string></string>
</property>
</widget>
- <widget class="QCheckBox" row="7" column="3">
+ <widget class="TQCheckBox" row="7" column="3">
<property name="name">
<cstring>CBox_15</cstring>
</property>
@@ -1020,7 +1020,7 @@
<string></string>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>genericTextLabel_9</cstring>
</property>
@@ -1043,7 +1043,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>121</height>
@@ -1249,11 +1249,11 @@
<slot>changed()</slot>
</connection>
</connections>
-<slots>
+<Q_SLOTS>
<slot>chanaged()</slot>
<slot>changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
<includehint>kcolorbutton.h</includehint>
diff --git a/ksirc/KSPrefs/page_looknfeel.cpp b/ksirc/KSPrefs/page_looknfeel.cpp
index 29608e04..f29523b8 100644
--- a/ksirc/KSPrefs/page_looknfeel.cpp
+++ b/ksirc/KSPrefs/page_looknfeel.cpp
@@ -16,7 +16,7 @@
#include <kfiledialog.h>
#include "page_looknfeel.h"
-PageLooknFeel::PageLooknFeel( TQWidget *parent, const char *name ) : PageLooknFeelBase( parent, name)
+PageLooknFeel::PageLooknFeel( TQWidget *tqparent, const char *name ) : PageLooknFeelBase( tqparent, name)
{
modePreview->setPixmap(TQPixmap(locate("data","ksirc/pics/sdi.png")));
wallpaperPathLE->fileDialog()->setFilter( "*.jpg *.png *.gif" );
diff --git a/ksirc/KSPrefs/page_looknfeel.h b/ksirc/KSPrefs/page_looknfeel.h
index 326498cb..cc9d0f08 100644
--- a/ksirc/KSPrefs/page_looknfeel.h
+++ b/ksirc/KSPrefs/page_looknfeel.h
@@ -16,9 +16,10 @@
class PageLooknFeel : public PageLooknFeelBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageLooknFeel( TQWidget *parent = 0, const char *name = 0 );
+ PageLooknFeel( TQWidget *tqparent = 0, const char *name = 0 );
~PageLooknFeel();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_looknfeelbase.ui b/ksirc/KSPrefs/page_looknfeelbase.ui
index 6aee3a14..ba4ea3f4 100644
--- a/ksirc/KSPrefs/page_looknfeelbase.ui
+++ b/ksirc/KSPrefs/page_looknfeelbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
<class>PageLooknFeelBase</class>
-<widget class="QFrame">
+<widget class="TQFrame">
<property name="name">
<cstring>PageLooknFeelBase</cstring>
</property>
@@ -12,7 +12,7 @@
<height>452</height>
</rect>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>425</width>
<height>450</height>
@@ -34,7 +34,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>windowModeGB</cstring>
</property>
@@ -61,14 +61,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>31</height>
</size>
</property>
</spacer>
- <widget class="QRadioButton" row="3" column="0">
+ <widget class="TQRadioButton" row="3" column="0">
<property name="name">
<cstring>mdiCB</cstring>
</property>
@@ -92,21 +92,21 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>31</height>
</size>
</property>
</spacer>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>wmLabel</cstring>
</property>
<property name="text">
<string>Choose your favorite window mode:</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter|AlignLeft</set>
</property>
<property name="vAlign" stdset="0">
@@ -114,7 +114,7 @@
<property name="wordwrap" stdset="0">
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0">
+ <widget class="TQRadioButton" row="2" column="0">
<property name="name">
<cstring>sdiCB</cstring>
</property>
@@ -128,17 +128,17 @@
<number>0</number>
</property>
</widget>
- <widget class="QFrame" row="1" column="1" rowspan="4" colspan="1">
+ <widget class="TQFrame" row="1" column="1" rowspan="4" colspan="1">
<property name="name">
<cstring>Frame3</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>120</width>
<height>120</height>
</size>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>120</width>
<height>120</height>
@@ -150,7 +150,7 @@
<property name="frameShadow">
<enum>Raised</enum>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>modePreview</cstring>
</property>
@@ -169,7 +169,7 @@
</widget>
</grid>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>wallpaperGB</cstring>
</property>
@@ -180,7 +180,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout4</cstring>
</property>
@@ -198,13 +198,13 @@
<property name="name">
<cstring>wallpaperPathLE</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>100</width>
<height>25</height>
</size>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>32767</width>
<height>30</height>
@@ -213,17 +213,17 @@
</widget>
</hbox>
</widget>
- <widget class="QFrame">
+ <widget class="TQFrame">
<property name="name">
<cstring>Frame3_2</cstring>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>120</width>
<height>120</height>
</size>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>120</width>
<height>120</height>
@@ -235,7 +235,7 @@
<property name="frameShadow">
<enum>Raised</enum>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>wallpaperPreview</cstring>
</property>
@@ -264,7 +264,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>51</width>
<height>1</height>
@@ -309,12 +309,12 @@
<tabstop>sdiCB</tabstop>
<tabstop>wallpaperPathLE</tabstop>
</tabstops>
-<slots>
+<Q_SLOTS>
<slot access="protected">setPreviewPixmap(bool)</slot>
<slot access="protected">showWallpaperPixmap(const QString &amp;)</slot>
<slot>changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kurlrequester.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/ksirc/KSPrefs/page_rmbmenu.cpp b/ksirc/KSPrefs/page_rmbmenu.cpp
index de30a829..c6bb24ee 100644
--- a/ksirc/KSPrefs/page_rmbmenu.cpp
+++ b/ksirc/KSPrefs/page_rmbmenu.cpp
@@ -20,7 +20,7 @@
-PageRMBMenu::PageRMBMenu( TQWidget *parent, const char *name ) : PageRMBMenuBase( parent, name)
+PageRMBMenu::PageRMBMenu( TQWidget *tqparent, const char *name ) : PageRMBMenuBase( tqparent, name)
{
UserControlMenu *ucm;
diff --git a/ksirc/KSPrefs/page_rmbmenu.h b/ksirc/KSPrefs/page_rmbmenu.h
index 1d4a8dac..39b8cd89 100644
--- a/ksirc/KSPrefs/page_rmbmenu.h
+++ b/ksirc/KSPrefs/page_rmbmenu.h
@@ -16,9 +16,10 @@
class PageRMBMenu : public PageRMBMenuBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageRMBMenu( TQWidget *parent = 0, const char *name = 0 );
+ PageRMBMenu( TQWidget *tqparent = 0, const char *name = 0 );
~PageRMBMenu();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_rmbmenubase.ui b/ksirc/KSPrefs/page_rmbmenubase.ui
index 1ef1e053..abeb6169 100644
--- a/ksirc/KSPrefs/page_rmbmenubase.ui
+++ b/ksirc/KSPrefs/page_rmbmenubase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>PageRMBMenuBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageRMBMenuBase</cstring>
</property>
@@ -22,11 +22,11 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>explLabel</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -41,7 +41,7 @@
<property name="text">
<string>This page allows configuration of the RMB Menu for the nicklist located on the right. You can define names for certain actions. Look at the predefined commands to learn how it works.</string>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter|AlignLeft</set>
</property>
<property name="buddy" stdset="0">
@@ -50,7 +50,7 @@
<property name="wordwrap" stdset="0">
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout28</cstring>
</property>
@@ -64,12 +64,12 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QListBox">
+ <widget class="TQListBox">
<property name="name">
<cstring>commandLB</cstring>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout26</cstring>
</property>
@@ -83,7 +83,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>entryNameLabel</cstring>
</property>
@@ -94,12 +94,12 @@
<cstring>entryLE</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>entryLE</cstring>
</property>
</widget>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>commandLabel</cstring>
</property>
@@ -110,12 +110,12 @@
<cstring>commandLE</cstring>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>commandLE</cstring>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>opEnableCB</cstring>
</property>
@@ -133,14 +133,14 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>20</height>
</size>
</property>
</spacer>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout24</cstring>
</property>
@@ -154,14 +154,14 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>moveUpPB</cstring>
</property>
<property name="enabled">
<bool>false</bool>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -171,14 +171,14 @@
<string>Move Down</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>moveDownPB</cstring>
</property>
<property name="enabled">
<bool>false</bool>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -200,14 +200,14 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>10</width>
<height>21</height>
</size>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>insertSeperatorPB</cstring>
</property>
@@ -215,7 +215,7 @@
<string>Insert &amp;Separator</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>insertItemPB</cstring>
</property>
@@ -223,7 +223,7 @@
<string>&amp;Insert Command</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>changeItemPB</cstring>
</property>
@@ -231,7 +231,7 @@
<string>M&amp;odify</string>
</property>
</widget>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>deleteItemPB</cstring>
</property>
@@ -248,5 +248,5 @@
<includes>
<include location="global" impldecl="in declaration">kseparator.h</include>
</includes>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksirc/KSPrefs/page_servchan.cpp b/ksirc/KSPrefs/page_servchan.cpp
index f7587947..e1ed6413 100644
--- a/ksirc/KSPrefs/page_servchan.cpp
+++ b/ksirc/KSPrefs/page_servchan.cpp
@@ -15,7 +15,7 @@
#include <kapplication.h>
#include <kconfig.h>
-PageServChan::PageServChan( TQWidget *parent, const char *name ) : PageServChanBase( parent, name)
+PageServChan::PageServChan( TQWidget *tqparent, const char *name ) : PageServChanBase( tqparent, name)
{
connect(serverDeleteItemPB, TQT_SIGNAL(pressed()), this, TQT_SLOT(deletePressedSL()));
connect(ServerAddItemPB, TQT_SIGNAL(pressed()), this, TQT_SLOT(addPressedSL()));
diff --git a/ksirc/KSPrefs/page_servchan.h b/ksirc/KSPrefs/page_servchan.h
index 1e20e8d7..8db7d223 100644
--- a/ksirc/KSPrefs/page_servchan.h
+++ b/ksirc/KSPrefs/page_servchan.h
@@ -16,9 +16,10 @@
class PageServChan : public PageServChanBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageServChan( TQWidget *parent = 0, const char *name = 0 );
+ PageServChan( TQWidget *tqparent = 0, const char *name = 0 );
~PageServChan();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_servchanbase.ui b/ksirc/KSPrefs/page_servchanbase.ui
index b24ce9dc..59ad646f 100644
--- a/ksirc/KSPrefs/page_servchanbase.ui
+++ b/ksirc/KSPrefs/page_servchanbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.0" stdsetdef="1">
<class>PageServChanBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageServChanBase</cstring>
</property>
@@ -22,7 +22,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>GroupBox33</cstring>
</property>
@@ -39,12 +39,12 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QListBox">
+ <widget class="TQListBox">
<property name="name">
<cstring>serverLB</cstring>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout15</cstring>
</property>
@@ -58,7 +58,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>serverDeleteItemPB</cstring>
</property>
@@ -77,7 +77,7 @@
<enum>Expanding</enum>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>ServerAddItemPB</cstring>
</property>
@@ -85,7 +85,7 @@
<string>Add &amp;Server to List</string>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>LineEdit6</cstring>
</property>
@@ -94,7 +94,7 @@
</widget>
</hbox>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>GroupBox34</cstring>
</property>
@@ -111,12 +111,12 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QListBox">
+ <widget class="TQListBox">
<property name="name">
<cstring>channelLB</cstring>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout15_2</cstring>
</property>
@@ -130,7 +130,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>chanDeleteItmPB</cstring>
</property>
@@ -149,7 +149,7 @@
<enum>Expanding</enum>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>ChanAddItemPB</cstring>
</property>
@@ -157,7 +157,7 @@
<string>Add Cha&amp;nnel to List</string>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>LineEdit6_2</cstring>
</property>
@@ -168,5 +168,5 @@
</widget>
</vbox>
</widget>
-<layoutdefaults spacing="6" margin="11"/>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksirc/KSPrefs/page_shortcuts.cpp b/ksirc/KSPrefs/page_shortcuts.cpp
index 4d2fda54..ab30824a 100644
--- a/ksirc/KSPrefs/page_shortcuts.cpp
+++ b/ksirc/KSPrefs/page_shortcuts.cpp
@@ -16,13 +16,13 @@
#include "page_shortcuts.h"
#include "../servercontroller.h"
-PageShortcuts::PageShortcuts( TQWidget *parent, const char *name ) : PageShortcutsBase( parent, name)
+PageShortcuts::PageShortcuts( TQWidget *tqparent, const char *name ) : PageShortcutsBase( tqparent, name)
{
globalGB->setColumnLayout( 0, Qt::Horizontal );
m_key = new KKeyChooser(servercontroller::self()->getGlobalAccel(), globalGB);
connect(m_key, TQT_SIGNAL(keyChange()), this, TQT_SLOT(changed()));
- globalGB->layout()->add(m_key);
+ globalGB->tqlayout()->add(m_key);
}
PageShortcuts::~PageShortcuts()
diff --git a/ksirc/KSPrefs/page_shortcuts.h b/ksirc/KSPrefs/page_shortcuts.h
index 36048f44..c551db9b 100644
--- a/ksirc/KSPrefs/page_shortcuts.h
+++ b/ksirc/KSPrefs/page_shortcuts.h
@@ -18,9 +18,10 @@ class KKeyChooser;
class PageShortcuts : public PageShortcutsBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageShortcuts( TQWidget *parent = 0, const char *name = 0 );
+ PageShortcuts( TQWidget *tqparent = 0, const char *name = 0 );
~PageShortcuts();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_shortcutsbase.ui b/ksirc/KSPrefs/page_shortcutsbase.ui
index 57f21647..c570f73f 100644
--- a/ksirc/KSPrefs/page_shortcutsbase.ui
+++ b/ksirc/KSPrefs/page_shortcutsbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>PageShortcutsBase</class>
-<widget class="QFrame">
+<widget class="TQFrame">
<property name="name">
<cstring>PageShortcutslBase</cstring>
</property>
@@ -12,7 +12,7 @@
<height>452</height>
</rect>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>425</width>
<height>450</height>
@@ -34,7 +34,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>globalGB</cstring>
</property>
@@ -48,10 +48,10 @@
</connections>
<tabstops>
</tabstops>
-<slots>
+<Q_SLOTS>
<slot access="protected">setPreviewPixmap(bool)</slot>
<slot access="protected">showWallpaperPixmap(const QString &amp;)</slot>
<slot>changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ksirc/KSPrefs/page_startup.cpp b/ksirc/KSPrefs/page_startup.cpp
index e2ddfdc1..37b3f875 100644
--- a/ksirc/KSPrefs/page_startup.cpp
+++ b/ksirc/KSPrefs/page_startup.cpp
@@ -19,7 +19,7 @@
#include "page_startup.h"
-PageStartup::PageStartup( TQWidget *parent, const char *name ) : PageStartupBase( parent, name)
+PageStartup::PageStartup( TQWidget *tqparent, const char *name ) : PageStartupBase( tqparent, name)
{
notifyLB->upButton()->hide();
notifyLB->downButton()->hide();
@@ -49,7 +49,7 @@ void PageStartup::saveConfig()
for( ; it != items.end(); ++it){
ksopts->server[*it] = server[*it];
}
- if(!ksopts->server.contains("global")){
+ if(!ksopts->server.tqcontains("global")){
ksopts->server["global"] = glb;
}
@@ -65,7 +65,7 @@ void PageStartup::readConfig( const KSOptions *opts )
if(it.data().globalCopy == false)
serverLB->insertItem(it.key());
}
- TQListBoxItem *item = serverLB->listBox()->findItem("global");
+ TQListBoxItem *item = serverLB->listBox()->tqfindItem("global");
serverLB->listBox()->setSelected(item, true);
changing = false;
clickedLB(serverLB->listBox()->index(item));
@@ -107,7 +107,7 @@ void PageStartup::clickedLB(int index)
{
TQString text = serverLB->text(index);
- if(!server.contains(text)){
+ if(!server.tqcontains(text)){
server[text] = server["global"];
server[text].globalCopy = true;
}
diff --git a/ksirc/KSPrefs/page_startup.h b/ksirc/KSPrefs/page_startup.h
index c2092e65..ab905770 100644
--- a/ksirc/KSPrefs/page_startup.h
+++ b/ksirc/KSPrefs/page_startup.h
@@ -16,9 +16,10 @@
class PageStartup : public PageStartupBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PageStartup( TQWidget *parent = 0, const char *name = 0 );
+ PageStartup( TQWidget *tqparent = 0, const char *name = 0 );
~PageStartup();
void saveConfig();
diff --git a/ksirc/KSPrefs/page_startupbase.ui b/ksirc/KSPrefs/page_startupbase.ui
index 1a248806..125b0934 100644
--- a/ksirc/KSPrefs/page_startupbase.ui
+++ b/ksirc/KSPrefs/page_startupbase.ui
@@ -1,6 +1,6 @@
<!DOCTYPE UI><UI version="3.1" stdsetdef="1">
<class>PageStartupBase</class>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>PageStartupBase</cstring>
</property>
@@ -38,11 +38,11 @@
<string>Server</string>
</property>
</widget>
- <widget class="QGroupBox">
+ <widget class="TQGroupBox">
<property name="name">
<cstring>nickGB</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -61,22 +61,22 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLineEdit" row="0" column="1">
+ <widget class="TQLineEdit" row="0" column="1">
<property name="name">
<cstring>nickLE</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="1" column="1">
+ <widget class="TQLineEdit" row="1" column="1">
<property name="name">
<cstring>altNickLE</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="2" column="1">
+ <widget class="TQLineEdit" row="2" column="1">
<property name="name">
<cstring>rnLE</cstring>
</property>
</widget>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>nickLabel</cstring>
</property>
@@ -87,7 +87,7 @@
<cstring>nickLE</cstring>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>anLabel</cstring>
</property>
@@ -98,12 +98,12 @@
<cstring>altNickLE</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="3" column="1">
+ <widget class="TQLineEdit" row="3" column="1">
<property name="name">
<cstring>uiLE</cstring>
</property>
</widget>
- <widget class="QLabel" row="3" column="0">
+ <widget class="TQLabel" row="3" column="0">
<property name="name">
<cstring>uiLabel</cstring>
</property>
@@ -114,7 +114,7 @@
<cstring>rnLE</cstring>
</property>
</widget>
- <widget class="QLabel" row="2" column="0">
+ <widget class="TQLabel" row="2" column="0">
<property name="name">
<cstring>rnLabel</cstring>
</property>
@@ -183,11 +183,11 @@
<slot>server_changed()</slot>
</connection>
</connections>
-<slots>
+<Q_SLOTS>
<slot>changed()</slot>
<slot>server_changed()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>keditlistbox.h</includehint>
<includehint>klineedit.h</includehint>
diff --git a/ksirc/KSPrefs/page_autoconnect.cpp b/ksirc/KSPrefs/page_autoconnect.cpp
index c9ab585d..9a6e61ab 100644
--- a/ksirc/KSPrefs/page_autoconnect.cpp
+++ b/ksirc/KSPrefs/page_autoconnect.cpp
@@ -26,7 +26,7 @@
#define PASS 2
#define SSL 3
-PageAutoConnect::PageAutoConnect( TQWidget *parent, const char *name ) : PageAutoConnectBase( parent, name)
+PageAutoConnect::PageAutoConnect( TQWidget *tqparent, const char *name ) : PageAutoConnectBase( tqparent, name)
{
KLVAutoConnect->setSorting( 0 );
//KLVAutoConnect->header()->hide();
@@ -59,7 +59,7 @@ void PageAutoConnect::saveConfig()
if(it->text(SSL).length() > 0)
server += " (SSL)";
if(it->text(PASS).length() > 0)
- server += TQString(" (pass: %1)").arg(it->text(PASS));
+ server += TQString(" (pass: %1)").tqarg(it->text(PASS));
servers << server;
@@ -73,7 +73,7 @@ void PageAutoConnect::saveConfig()
channel = ch->text(NAME);
if(ch->text(PK).length() > 0)
- channel += TQString(" (key: %1)").arg(ch->text(PK));
+ channel += TQString(" (key: %1)").tqarg(ch->text(PK));
channels << channel;
@@ -101,8 +101,8 @@ void PageAutoConnect::readConfig()
TQStringList channels = conf->readListEntry(*ser);
TQString server = *ser;
TQString port = "6667";
- TQString ssl = TQString::null;
- TQString pass = TQString::null;
+ TQString ssl = TQString();
+ TQString pass = TQString();
TQRegExp rx("(.+) \\(SSL\\)(.*)");
if(rx.search(server) >= 0){
@@ -127,7 +127,7 @@ void PageAutoConnect::readConfig()
TQStringList::ConstIterator chan = channels.begin();
for(; chan != channels.end(); chan++){
TQString channel = *chan;
- TQString key = TQString::null;
+ TQString key = TQString();
TQRegExp crx("(.+) \\(key: (\\S+)\\)");
if(crx.search(channel) >= 0){
channel = crx.cap(1);
@@ -157,7 +157,7 @@ void PageAutoConnect::add_pressed()
s = KLVAutoConnect->selectedItem();
if(!s){ /* new item */
TQString server = ServerLE->text();
- TQString ssl = TQString::null;
+ TQString ssl = TQString();
TQString port;
port.setNum(PortKI->value());
@@ -170,25 +170,25 @@ void PageAutoConnect::add_pressed()
KLVAutoConnect->setCurrentItem(s);
}
else { /* update the existing one */
- TQListViewItem *parent;
+ TQListViewItem *tqparent;
TQListViewItem *child;
- if(s->parent()){
- parent = s->parent();
+ if(s->tqparent()){
+ tqparent = s->tqparent();
child = s;
}
else {
- parent = s;
+ tqparent = s;
child = 0x0;
}
- parent->setText(NAME, ServerLE->text());
- parent->setText(PK, TQString("%1").arg(PortKI->value()));
- parent->setText(PASS, PassLE->text());
+ tqparent->setText(NAME, ServerLE->text());
+ tqparent->setText(PK, TQString("%1").tqarg(PortKI->value()));
+ tqparent->setText(PASS, PassLE->text());
if(sslCB->isChecked())
- parent->setText(SSL, i18n("SSL"));
+ tqparent->setText(SSL, i18n("SSL"));
else
- parent->setText(SSL, TQString::null);
+ tqparent->setText(SSL, TQString());
if(child){
child->setText(NAME, ChannelLE->text());
@@ -197,7 +197,7 @@ void PageAutoConnect::add_pressed()
else {
if(ChannelLE->text().length() > 0){
fnd = 0;
- TQListViewItem *c = parent->firstChild();
+ TQListViewItem *c = tqparent->firstChild();
for( ; c != 0 && fnd == 0; c = c->nextSibling()){
if(c->text(NAME) == ChannelLE->text()){
c->setText(PK, KeyLE->text());
@@ -205,7 +205,7 @@ void PageAutoConnect::add_pressed()
}
}
if(fnd == 0){
- new TQListViewItem(parent, ChannelLE->text(), KeyLE->text());
+ new TQListViewItem(tqparent, ChannelLE->text(), KeyLE->text());
}
}
}
@@ -260,16 +260,16 @@ void PageAutoConnect::delete_pressed()
void PageAutoConnect::kvl_clicked(TQListViewItem *it)
{
if(it != 0){
- if(it->parent() != 0){
+ if(it->tqparent() != 0){
ChannelLE->setText(it->text(NAME));
KeyLE->setText(it->text(PK));
AddPB->setText(i18n("&Update"));
/*
* Move it to the parent to setup parent/server
* values. This save writing this code
* in two places.
*/
- it = it->parent();
+ it = it->tqparent();
}
else {
AddPB->setText(i18n("&Update/Add"));
@@ -277,7 +277,7 @@ void PageAutoConnect::kvl_clicked(TQListViewItem *it)
KeyLE->clear();
}
- if(it->parent() == 0){
+ if(it->tqparent() == 0){
ServerLE->setText(it->text(NAME));
PortKI->setValue(it->text(PK).toInt());
PassLE->setText(it->text(PASS));
@@ -260,16 +260,16 @@ void PageAutoConnect::delete_pressed()
AddPB->setText(i18n("&Update"));
/*
- * Move it to the parent to setup parent/server
+ * Move it to the tqparent to setup tqparent/server
* values. This save writing this code
* in two places.